==> kolourpaint-4.9.5.tar.xz: kolourpaint-4.9.5/commands/kpCommand.cpp <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#define DEBUG_KP_COMMAND_HISTORY 0


#include <kpCommand.h>

#include <kpCommandEnvironment.h>


kpCommand::kpCommand (kpCommandEnvironment *environ)
    : m_environ (environ)
{
    Q_ASSERT (environ);
}

kpCommand::~kpCommand ()
{
}


kpCommandEnvironment *kpCommand::environ () const
{
    return m_environ;
}


// protected
kpDocument *kpCommand::document () const
{
    return m_environ->document ();
}


// protected
kpAbstractSelection *kpCommand::selection () const
{
    return m_environ->selection ();
}

// protected
kpAbstractImageSelection *kpCommand::imageSelection () const
{
    return m_environ->imageSelection ();
}

// protected
kpTextSelection *kpCommand::textSelection () const
{
    return m_environ->textSelection ();
}


// protected
kpViewManager *kpCommand::viewManager () const
{
    return m_environ->viewManager ();
}

==> kolourpaint_18.12.3.orig.tar.xz: kolourpaint-18.12.3/commands/kpCommand.cpp <==

/*
   Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>
   All rights reserved.

   Redistribution and use in source and binary forms, with or without
   modification, are permitted provided that the following conditions
   are met:

   1. Redistributions of source code must retain the above copyright
      notice, this list of conditions and the following disclaimer.
   2. Redistributions in binary form must reproduce the above copyright
      notice, this list of conditions and the following disclaimer in the
      documentation and/or other materials provided with the distribution.

   THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
   IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
   OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
   IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
   INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
   NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
   DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
   THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
   (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
   THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/


#define DEBUG_KP_COMMAND_HISTORY 0


#include "kpCommand.h"

#include "environments/commands/kpCommandEnvironment.h"


kpCommand::kpCommand (kpCommandEnvironment *environ)
    : m_environ (environ)
{
    Q_ASSERT (environ);
}

kpCommand::~kpCommand ()
{
}


kpCommandEnvironment *kpCommand::environ () const
{
    return m_environ;
}


// protected
kpDocument *kpCommand::document () const
{
    return m_environ->document ();
}


// protected
kpAbstractSelection *kpCommand::selection () const
{
    return m_environ->selection ();
}

// protected
kpAbstractImageSelection *kpCommand::imageSelection () const
{
    return m_environ->imageSelection ();
}

// protected
kpTextSelection *kpCommand::textSelection () const
{
    return m_environ->textSelection ();
}


// protected
kpViewManager *kpCommand::viewManager () const
{
    return m_environ->viewManager ();
}
